Object.prototype.BREAKOUT_NULL = 0;
Object.prototype.BREAKOUT_LOADING_VARS = 2;
Object.prototype.BREAKOUT_BEGINNING_LEVEL_PROMPT = 4;
Object.prototype.BREAKOUT_PLAYING = 8;
Object.prototype.BREAKOUT_QUIZZING = 16;
Object.prototype.BREAKOUT_QUIZZING_OUT = 32;
Object.prototype.BREAKOUT_NO_POWER_UP = 0;
Object.prototype.BREAKOUT_SUPER_BALL = 2;
Object.prototype.BREAKOUT_GRAVITY_BALL = 4;
Object.prototype.BREAKOUT_SLOW_BALL = 8;
Object.prototype.BREAKOUT_FAST_BALL = 16;
Object.prototype.BREAKOUT_EXTRA_BALL = 32;
Object.prototype.BREAKOUT_LARGE_BALL = 64;
Object.prototype.BREAKOUT_SMALL_BALL = 128;
Object.prototype.BREAKOUT_SPEED_INCREASE = 256;
Breakout = function()
{
   this.load_game_data();
};
Breakout.prototype.board_data_file = board_data_file;
Breakout.prototype.shuffle_levels = shuffle_levels;
Breakout.prototype.paddle_enlarge_width = Number(paddle_enlarge_width);
Breakout.prototype.paddle_shrink_width = Number(paddle_shrink_width);
Breakout.prototype.remove_blank_blocks = "True";
Breakout.prototype.paddle_linkage_names = paddle_linkage_names;
Breakout.prototype.ball_linkage_names = ball_linkage_names;
Breakout.prototype.quiz_correct_points = quiz_correct_points.toNumber();
Breakout.prototype.quiz_incorrect_points = quiz_incorrect_points.toNumber();
Breakout.prototype.stage_width = Number(stage_width);
Breakout.prototype.stage_height = Number(stage_height);
Breakout.prototype.total_num_lives = Number(total_num_lives);
Breakout.prototype.block_hit_points = block_hit_points.toNumber();
Breakout.prototype.timeline = this;
Breakout.prototype.load_game_data = function()
{
   var _loc1_ = this;
   _loc1_.mode = BREAKOUT_LOADING_VARS;
   _loc1_.timeline.controller.loadVariables(_loc1_.board_data_file);
};
Breakout.prototype.initialize = function()
{
   var _loc1_ = this;
   _loc1_.initialize_variables();
   _loc1_.initialize_graphics();
   _loc1_.initialize_current_level();
};
Breakout.prototype.initialize_variables = function()
{
   var _loc1_ = this;
   _loc1_.mode = BREAKOUT_BEGINNING_LEVEL_PROMPT;
   _loc1_.current_power_up = BREAKOUT_NO_POWER_UP;
   _loc1_.background_width = _loc1_.timeline.background_area._width;
   _loc1_.background_height = _loc1_.timeline.background_area._height;
   _loc1_.board_piece_width = _loc1_.background_width / _loc1_.board_dim_x;
   _loc1_.board_piece_height = _loc1_.background_height / _loc1_.board_dim_y;
   if(_loc1_.shuffle_levels == "True")
   {
      _loc1_.levels.shuffle();
   }
   _loc1_.current_level = 0;
   _loc1_.balls = new Array();
   _loc1_.power_up_names = ["1 Life","-1 Life","+ Points","- Points","Super Ball","Quiz","Slow Ball","Fast Ball","Extra Ball","Large Paddle","Small Paddle","Speed Increase"];
   _loc1_.num_lives = _loc1_.total_num_lives;
   _loc1_.score = 0;
   _loc1_.super_ball_active = false;
   _loc1_.depth = 0;
};
Breakout.prototype.initialize_graphics = function()
{
   this.create_board_pieces();
};
Breakout.prototype.create_board_pieces = function()
{
   var _loc1_ = this;
   var j = 0;
   while(j < _loc1_.board_dim_x)
   {
      var _loc3_ = 0;
      while(_loc3_ < _loc1_.board_dim_y)
      {
         _loc1_.timeline.attachMovie("breakout_piece","piece_" + j + "_" + _loc3_,_loc1_.depth++);
         var _loc2_ = _loc1_.timeline["piece_" + j + "_" + _loc3_];
         _loc2_._width = _loc1_.board_piece_width;
         _loc2_._height = _loc1_.board_piece_height;
         _loc2_._x = _loc1_.timeline.background_area._x + j * _loc1_.board_piece_width;
         _loc2_._y = _loc1_.timeline.background_area._y + _loc3_ * _loc1_.board_piece_height;
         _loc2_.index_x = j;
         _loc2_.index_y = _loc3_;
         _loc3_ = _loc3_ + 1;
      }
      j++;
   }
};
Breakout.prototype.create_paddle = function()
{
   var _loc1_ = this;
   if(_loc1_.timeline.paddle != undefined)
   {
      _loc1_.timeline.paddle.removeMovieClip();
   }
   _loc1_.timeline.attachMovie(_loc1_.paddle_linkage_names[_loc1_.current_level],"paddle",_loc1_.depth++);
   var _loc2_ = _loc1_.timeline.paddle;
   _loc2_._x = _loc1_.timeline.background_area._x + _loc1_.background_width / 2;
   _loc2_._y = _loc1_.timeline.background_area._y + _loc1_.background_height - _loc2_._height / 2;
   _loc1_.paddle_width = _loc2_._width;
};
Breakout.prototype.initialize_current_level = function()
{
   var _loc1_ = this;
   _loc1_.initialize_level_variables();
   _loc1_.create_paddle();
   _loc1_.remove_balls();
   _loc1_.add_ball();
   _loc1_.render_level_board();
   _loc1_.prompt_current_level();
};
Breakout.prototype.initialize_level_variables = function()
{
   var _loc1_ = this;
   _loc1_.mode = BREAKOUT_BEGINNING_LEVEL_PROMPT;
   _loc1_.current_ball_speed = _loc1_.levels[_loc1_.current_level].initial_ball_speed;
   _loc1_.super_ball_active = false;
   _loc1_.timeline.background_area.gotoAndStop(_loc1_.current_level + 1);
};
Breakout.prototype.remove_balls = function()
{
   var _loc3_ = this;
   var _loc1_ = 0;
   while(_loc1_ < _loc3_.balls.length)
   {
      var _loc2_ = _loc3_.balls.pop();
      _loc2_.removeMovieClip();
      _loc1_ = _loc1_ + 1;
   }
};
Breakout.prototype.add_ball = function()
{
   var _loc1_ = this;
   var level = _loc1_.levels[_loc1_.current_level];
   _loc1_.timeline.attachMovie(_loc1_.ball_linkage_names[_loc1_.current_level],"ball" + _loc1_.balls.length,_loc1_.depth++);
   var _loc2_ = _loc1_.timeline["ball" + _loc1_.balls.length];
   _loc2_._x = _loc1_.timeline.paddle._x;
   _loc2_._y = _loc1_.timeline.paddle._y - _loc2_._height;
   var _loc3_ = Math.randf(0.75,0.25) * 3.141592653589793;
   _loc2_.velocity_x = _loc1_.current_ball_speed * Math.cos(_loc3_);
   _loc2_.velocity_y = (- _loc1_.current_ball_speed) * Math.sin(_loc3_);
   _loc1_.balls.push(_loc2_);
};
Breakout.prototype.render_level_board = function()
{
   var _loc3_ = this.levels[this.current_level];
   this.blocks = new Array();
   var j = 0;
   while(j < this.board_dim_x)
   {
      var _loc2_ = 0;
      while(_loc2_ < this.board_dim_y)
      {
         var _loc1_ = this.timeline["piece_" + j + "_" + _loc2_];
         _loc1_.piece_index = _loc3_.board[j][_loc2_];
         if(_loc3_.power_up_type == "Random")
         {
            if(_loc3_.board[j][_loc2_] >= _loc3_.num_regular_pieces)
            {
               _loc1_.gotoAndStop(_loc3_.num_regular_pieces + 1);
            }
            else
            {
               _loc1_.gotoAndStop(_loc3_.board[j][_loc2_] + 1);
            }
         }
         else
         {
            _loc1_.gotoAndStop(_loc3_.board[j][_loc2_] + 1);
            if(_loc1_._currentframe > _loc3_.num_regular_pieces + 1)
            {
               this.calculate_powerup_properties(_loc1_);
            }
         }
         if(_loc1_.piece_index != 0)
         {
            _loc1_._visible = true;
            this.blocks.push(_loc1_);
         }
         else if(this.remove_blank_blocks == "True")
         {
            _loc1_._visible = false;
         }
         _loc2_ = _loc2_ + 1;
      }
      j++;
   }
   if(_loc3_.power_up_type == "Random")
   {
      this.sprinkle_power_ups();
   }
};
Breakout.prototype.sprinkle_power_ups = function()
{
   var level = this.levels[this.current_level];
   var _loc2_ = 0;
   while(_loc2_ < level.num_power_ups)
   {
      var _loc1_ = this.blocks.rande();
      var _loc3_ = level.possible_power_ups.rande();
      _loc1_.gotoAndStop(_loc3_);
      this.calculate_powerup_properties(_loc1_);
      _loc2_ = _loc2_ + 1;
   }
};
Breakout.prototype.calculate_powerup_properties = function(_mc)
{
   var _loc1_ = this;
   var _loc2_ = _mc;
   var _loc3_ = _loc1_.levels[_loc1_.current_level];
   _loc2_.piece.label = _loc1_.power_up_names[_loc2_._currentframe - (_loc3_.num_regular_pieces + 2)];
   _loc2_.swapDepths(_loc1_.depth++);
};
Breakout.prototype.prompt_current_level = function()
{
   var _loc1_ = this;
   var _loc3_ = _loc1_.levels[_loc1_.current_level];
   _loc1_.timeline.attachMovie("breakout_level_prompt","breakout_level_prompt",_loc1_.depth++);
   var _loc2_ = _loc1_.timeline.breakout_level_prompt;
   _loc2_._x = _loc1_.stage_width / 2;
   _loc2_._y = _loc1_.stage_height / 2;
   _loc2_.title = _loc3_.name;
   _loc2_.text = _loc3_.opening_text;
};
Breakout.prototype.close_prompt = function()
{
   this.mode = BREAKOUT_PLAYING;
   this.timeline.breakout_level_prompt.removeMovieClip();
};
Breakout.prototype.action = function()
{
   var _loc1_ = this;
   if(_loc1_.mode & BREAKOUT_PLAYING)
   {
      _loc1_.position_paddle();
      _loc1_.move_all_balls();
      _loc1_.check_done_power_ups();
   }
   _loc1_.timeline.score = _loc1_.score;
   _loc1_.timeline.num_lives = _loc1_.num_lives;
   _loc1_.timeline.current_level = _loc1_.current_level + 1;
};
Breakout.prototype.position_paddle = function()
{
   var _loc1_ = this;
   _loc1_.timeline.paddle._x = _root._xmouse;
   if(_loc1_.timeline.paddle._x - _loc1_.timeline.paddle._width / 2 < _loc1_.timeline.background_area._x)
   {
      _loc1_.timeline.paddle._x = _loc1_.timeline.background_area._x + _loc1_.timeline.paddle._width / 2;
   }
   else if(_loc1_.timeline.paddle._x + _loc1_.timeline.paddle._width / 2 > _loc1_.timeline.background_area._x + _loc1_.background_width)
   {
      _loc1_.timeline.paddle._x = _loc1_.timeline.background_area._x + _loc1_.background_width - _loc1_.timeline.paddle._width / 2;
   }
};
Breakout.prototype.move_all_balls = function()
{
   var _loc3_ = this;
   var _loc1_ = 0;
   while(_loc1_ < _loc3_.balls.length)
   {
      var _loc2_ = _loc3_.balls[_loc1_];
      _loc3_.move_ball(_loc2_);
      _loc1_ = _loc1_ + 1;
   }
};
Breakout.prototype.move_ball = function(ball_mc)
{
   var _loc1_ = ball_mc;
   var _loc2_ = this;
   _loc1_.old_x = _loc1_._x;
   _loc1_.old_y = _loc1_._y;
   _loc1_._x += _loc1_.velocity_x;
   _loc1_._y += _loc1_.velocity_y;
   _loc2_.check_ball_hit_boundaries(_loc1_);
   _loc2_.check_ball_hit_blocks(_loc1_);
   _loc2_.check_ball_hit_paddle(_loc1_);
   _loc2_.check_ball_off_score(_loc1_);
};
Breakout.prototype.check_ball_hit_boundaries = function(ball_mc)
{
   var _loc1_ = ball_mc;
   var _loc2_ = this.timeline.background_area;
   if(_loc1_._x - _loc1_._width / 2 <= _loc2_._x)
   {
      _loc1_._x = _loc2_._x + _loc1_._width / 2;
      _loc1_.velocity_x *= -1;
      _loc1_.gotoAndStop("Hit Boundary");
   }
   else if(_loc1_._x + _loc1_._width / 2 >= _loc2_._x + _loc2_._width)
   {
      _loc1_._x = _loc2_._x + _loc2_._width - _loc1_._width / 2;
      _loc1_.velocity_x *= -1;
      _loc1_.gotoAndStop("Hit Boundary");
   }
   else if(_loc1_._y - _loc1_._height / 2 <= _loc2_._y)
   {
      _loc1_._y = _loc2_._y + _loc1_._height / 2;
      _loc1_.velocity_y *= -1;
      _loc1_.gotoAndStop("Hit Boundary");
   }
};
Breakout.prototype.check_ball_hit_blocks = function(ball_mc)
{
   var _loc2_ = this;
   var level = _loc2_.levels[_loc2_.current_level];
   var _loc3_ = 0;
   while(_loc3_ < _loc2_.blocks.length)
   {
      var _loc1_ = _loc2_.blocks[_loc3_];
      if(_loc1_.hitTest(ball_mc))
      {
         if(_loc2_.check_for_complete_hit(ball_mc,_loc1_))
         {
            _loc2_.check_hit_power_up(_loc1_);
            if(_loc1_._currentframe > level.num_regular_pieces + 1)
            {
               ball_mc.gotoAndStop("Hit Power Up");
            }
            else
            {
               ball_mc.gotoAndStop("Hit Regular");
            }
            _loc1_.piece.play();
            _loc2_.blocks.remove_element(_loc1_);
            _loc2_.check_level_done();
         }
      }
      _loc3_ = _loc3_ + 1;
   }
};
Breakout.prototype.check_for_complete_hit = function(ball_mc, block_mc)
{
   var _loc1_ = ball_mc;
   var _loc3_ = _loc1_._x;
   var ball_y = _loc1_._y;
   var _loc2_ = block_mc._x;
   var block_y = block_mc._y;
   var ball_radius = _loc1_._width / 2;
   var block_width = block_mc._width;
   var block_height = block_mc._height;
   if(this.super_ball_active)
   {
      return true;
   }
   if(_loc3_ > _loc2_ && _loc3_ < _loc2_ + block_width && _loc1_.velocity_y > 0)
   {
      _loc1_._y = block_y - ball_radius;
      _loc1_.velocity_y *= -1;
      return true;
   }
   if(_loc3_ > _loc2_ && _loc3_ < _loc2_ + block_width && _loc1_.velocity_y < 0)
   {
      _loc1_._y = block_y + block_height + ball_radius;
      _loc1_.velocity_y *= -1;
      return true;
   }
   if(ball_y > block_y && ball_y < block_y + block_height && _loc3_ < _loc2_ && _loc1_.velocity_x > 0)
   {
      _loc1_._x = _loc2_ - ball_radius;
      _loc1_.velocity_x *= -1;
      return true;
   }
   if(ball_y > block_y && ball_y < block_y + block_height && _loc3_ > _loc2_ + block_width && _loc1_.velocity_x < 0)
   {
      _loc1_._x = _loc2_ + block_width + ball_radius;
      _loc1_.velocity_x *= -1;
      return true;
   }
   return false;
};
Breakout.prototype.check_hit_power_up = function(block_mc)
{
   var _loc1_ = this;
   var _loc2_ = block_mc;
   var _loc3_ = _loc1_.levels[_loc1_.current_level];
   if(_loc2_._currentframe > _loc3_.num_regular_pieces + 1)
   {
      if(_loc2_.piece.label == "1 Life")
      {
         _loc1_.plus_life();
      }
      else if(_loc2_.piece.label == "-1 Life")
      {
         _loc1_.minus_life();
      }
      else if(_loc2_.piece.label == "+ Points")
      {
         _loc1_.plus_points();
      }
      else if(_loc2_.piece.label == "- Points")
      {
         _loc1_.minus_points();
      }
      else if(_loc2_.piece.label == "Super Ball")
      {
         _loc1_.get_super_ball();
      }
      else if(_loc2_.piece.label == "Quiz")
      {
         _loc1_.get_quiz();
      }
      else if(_loc2_.piece.label == "Slow Ball")
      {
         _loc1_.get_slow_ball();
      }
      else if(_loc2_.piece.label == "Fast Ball")
      {
         _loc1_.get_fast_ball();
      }
      else if(_loc2_.piece.label == "Extra Ball")
      {
         _loc1_.get_extra_ball();
      }
      else if(_loc2_.piece.label == "Large Paddle")
      {
         _loc1_.get_large_paddle();
      }
      else if(_loc2_.piece.label == "Small Paddle")
      {
         _loc1_.get_small_paddle();
      }
      else if(_loc2_.piece.label == "Speed Increase")
      {
         _loc1_.get_speed_increase();
      }
   }
   else
   {
      _loc1_.score += _loc1_.block_hit_points[_loc1_.current_level];
   }
};
Breakout.prototype.plus_life = function()
{
   this.num_lives = this.num_lives + 1;
};
Breakout.prototype.minus_life = function()
{
   var _loc1_ = this;
   _loc1_.num_lives = _loc1_.num_lives - 1;
   if(_loc1_.num_lives <= 0)
   {
      _loc1_.num_lives = 1;
   }
};
Breakout.prototype.plus_points = function()
{
   var _loc1_ = this;
   _loc1_.score += _loc1_.levels[_loc1_.current_level].power_up_points;
};
Breakout.prototype.minus_points = function()
{
   var _loc1_ = this;
   _loc1_.score -= _loc1_.levels[_loc1_.current_level].power_up_points;
};
Breakout.prototype.get_super_ball = function()
{
   this.super_ball_active = true;
   this.super_ball_start = getTimer();
};
Breakout.prototype.get_quiz = function()
{
   var level = this.levels[this.current_level];
   var _loc3_ = level.questions.pop();
   this.timeline.attachMovie("breakout_quiz","breakout_quiz",this.depth++);
   var _mc = this.timeline.breakout_quiz;
   _mc._x = this.stage_width / 2;
   _mc._y = this.stage_height / 2;
   _mc.title = _loc3_.title;
   _mc.text = _loc3_.text;
   var _loc1_ = 0;
   while(_loc1_ < this.num_choices_per_question)
   {
      var _loc2_ = _mc["choice" + _loc1_];
      _loc2_.index = String.fromCharCode(65 + _loc1_);
      _loc2_.choice_text = _loc3_.choices[_loc1_];
      _loc2_.correct = _loc1_ == _loc3_.answer;
      _loc1_ = _loc1_ + 1;
   }
   this.mode = BREAKOUT_QUIZZING;
};
Breakout.prototype.get_slow_ball = function()
{
   var _loc1_ = this;
   var _loc2_ = _loc1_.levels[_loc1_.current_level];
   _loc1_.set_balls_speed(_loc1_.current_ball_speed - _loc2_.speed_increase);
   _loc1_.speed_change_start = getTimer();
};
Breakout.prototype.get_fast_ball = function()
{
   var _loc1_ = this;
   var _loc2_ = _loc1_.levels[_loc1_.current_level];
   _loc1_.set_balls_speed(_loc1_.current_ball_speed + _loc2_.speed_increase);
   _loc1_.speed_change_start = getTimer();
};
Breakout.prototype.get_extra_ball = function()
{
   this.num_lives = this.num_lives + 1;
   this.add_ball();
};
Breakout.prototype.get_large_paddle = function()
{
   this.timeline.paddle.gotoAndStop("Large Paddle");
   this.paddle_change_start = getTimer();
};
Breakout.prototype.get_small_paddle = function()
{
   this.timeline.paddle.gotoAndStop("Small Paddle");
   this.paddle_change_start = getTimer();
};
Breakout.prototype.get_speed_increase = function()
{
   var _loc1_ = this;
   var _loc2_ = _loc1_.levels[_loc1_.current_level];
   if(_loc1_.current_ball_speed == _loc2_.initial_ball_speed)
   {
      _loc1_.current_ball_speed += _loc2_.speed_increase;
      _loc1_.set_balls_speed(_loc1_.current_ball_speed);
   }
};
Breakout.prototype.set_balls_speed = function(speed)
{
   var _loc2_ = 0;
   while(_loc2_ < this.balls.length)
   {
      var _loc1_ = this.timeline["ball" + _loc2_];
      var _loc3_ = Math.sqrt(_loc1_.velocity_x * _loc1_.velocity_x + _loc1_.velocity_y * _loc1_.velocity_y);
      _loc1_.velocity_x = _loc1_.velocity_x / _loc3_ * speed;
      _loc1_.velocity_y = _loc1_.velocity_y / _loc3_ * speed;
      _loc2_ = _loc2_ + 1;
   }
};
Breakout.prototype.check_ball_hit_paddle = function(ball_mc)
{
   var _loc1_ = ball_mc;
   var _loc2_ = this;
   if(_loc1_.hitTest(_loc2_.timeline.paddle))
   {
      _loc1_._y = _loc2_.timeline.paddle._y - _loc2_.timeline.paddle._height / 2 - _loc1_._height / 2;
      var original_speed = Math.sqrt(_loc1_.velocity_x * _loc1_.velocity_x + _loc1_.velocity_y * _loc1_.velocity_y);
      _loc1_.velocity_x += (_loc1_._x - _loc2_.timeline.paddle._x) / 10;
      _loc1_.velocity_y *= -1;
      var _loc3_ = Math.sqrt(_loc1_.velocity_x * _loc1_.velocity_x + _loc1_.velocity_y * _loc1_.velocity_y);
      _loc1_.velocity_x = _loc1_.velocity_x / _loc3_ * original_speed;
      _loc1_.velocity_y = _loc1_.velocity_y / _loc3_ * original_speed;
      _loc1_.gotoAndStop("Hit Paddle");
      _loc2_.timeline.paddle.paddle.gotoAndPlay(1);
   }
};
Breakout.prototype.check_ball_off_score = function(ball_mc)
{
   var _loc1_ = this;
   var _loc2_ = ball_mc;
   if(_loc2_._y - _loc2_._height / 2 >= _loc1_.timeline.background_area._y + _loc1_.timeline.background_area._height)
   {
      _loc2_._y = _loc1_.timeline.background_area._y + _loc1_.timeline.background_area._height - _loc2_._height / 2;
      _loc1_.balls.remove_element(_loc2_);
      _loc2_.gotoAndStop("Fall Off Screen");
      _loc1_.num_lives = _loc1_.num_lives - 1;
      if(_loc1_.num_lives <= 0)
      {
         _root.score = _loc1_.score;
         _root.gotoAndStop("Lose");
      }
   }
};
Breakout.prototype.piece_animation_done = function(_mc)
{
   var _loc1_ = _mc;
   if(this.remove_blank_blocks == "True")
   {
      _loc1_._visible = false;
   }
   _loc1_.piece_index = 0;
   _loc1_.gotoAndStop(1);
};
Breakout.prototype.check_done_power_ups = function()
{
   var _loc1_ = this;
   var _loc2_ = _loc1_.levels[_loc1_.current_level];
   if(getTimer() - _loc1_.super_ball_start >= _loc2_.power_up_time && _loc1_.super_ball_active)
   {
      _loc1_.super_ball_active = false;
   }
   if(getTimer() - _loc1_.speed_change_start >= _loc2_.power_up_time)
   {
      _loc1_.set_balls_speed(_loc1_.current_ball_speed);
   }
   if(getTimer() - _loc1_.paddle_change_start >= _loc2_.power_up_time)
   {
      _loc1_.timeline.paddle.gotoAndStop("Normal Paddle");
   }
};
Breakout.prototype.check_level_done = function()
{
   var _loc1_ = this;
   if(_loc1_.blocks.length == 0)
   {
      if(_loc1_.current_level == _loc1_.num_levels - 1)
      {
         _root.score = _loc1_.score;
         _root.gotoAndStop("Win");
      }
      else
      {
         _loc1_.current_level = _loc1_.current_level + 1;
         _loc1_.initialize_current_level();
      }
   }
};
Breakout.prototype.handle_dead_ball = function()
{
   if(this.balls.length == 0)
   {
      this.add_ball();
   }
};
Breakout.prototype.player_guessed = function(choice_mc)
{
   if(choice_mc.correct)
   {
      this.handle_correct_answer();
   }
   else
   {
      this.handle_incorrect_answer();
   }
};
Breakout.prototype.handle_correct_answer = function()
{
   var _loc3_ = this;
   if(_loc3_.mode & BREAKOUT_QUIZZING)
   {
      _loc3_.timeline.breakout_quiz.text = "That is correct!  You earned " + _loc3_.quiz_correct_points[_loc3_.current_level] + " points!";
      var _loc1_ = 0;
      while(_loc1_ < _loc3_.num_choices_per_question)
      {
         var _loc2_ = _loc3_.timeline.breakout_quiz["choice" + _loc1_];
         if(!_loc2_.correct)
         {
            _loc2_.unloadMovie();
         }
         _loc1_ = _loc1_ + 1;
      }
      _loc3_.score += _loc3_.quiz_correct_points[_loc3_.current_level];
      _loc3_.timeline.breakout_quiz.play();
      _loc3_.mode = BREAKOUT_QUIZZING_OUT;
   }
};
Breakout.prototype.handle_incorrect_answer = function()
{
   var _loc3_ = this;
   if(_loc3_.mode & BREAKOUT_QUIZZING)
   {
      _loc3_.timeline.breakout_quiz.text = "Sorry, that is incorrect!  You lost " + Math.abs(_loc3_.quiz_incorrect_points[_loc3_.current_level]) + " points!";
      var _loc1_ = 0;
      while(_loc1_ < _loc3_.num_choices_per_question)
      {
         var _loc2_ = _loc3_.timeline.breakout_quiz["choice" + _loc1_];
         if(!_loc2_.correct)
         {
            _loc2_.unloadMovie();
         }
         _loc1_ = _loc1_ + 1;
      }
      _loc3_.score += _loc3_.quiz_incorrect_points[_loc3_.current_level];
      _loc3_.timeline.breakout_quiz.play();
      _loc3_.mode = BREAKOUT_QUIZZING_OUT;
   }
};
Breakout.prototype.quiz_animated_out = function()
{
   this.mode = BREAKOUT_PLAYING;
};
